@@ -1,4 +1,4 @@
-from ._exec import os_exec
+from zcmds.cmds.win32._exec import os_exec
 
 CMD = r"where"
 
